"""Nuke internal menu.py which will register all UI elements and callbacks."""

# Import third-party modules
import nuke

# Import local modules
from smartLog import osl as smartlog
from smartLog import nuke_funcs
from smartLog import idle
from smartLog.mvc import gui_helper
from smartLog.pys import QtCore
# Although these imports are unused here, they are still needed for registering
# custom commands and custom fields inside time logs. Please keep these lines,
# otherwise custom commands and custom time log fields won't get registered to
# smartLog.
from smartLog.custom import commands  # pylint: disable=unused-import
from smartLog.custom import timelog_fields  # pylint: disable=unused-import


def init():
    """Initialize time logger, time tracker, idle detection and UI commands."""
    smartlog.init()
    add_to_ui()


def add_to_ui():
    """Add smartLog commands to Nuke's UI."""
    logo = gui_helper.load_icons()["logo"]
    menu = nuke.menu("Nuke").addMenu("cragl/smartLog", logo)

    menu.addCommand("smartLog", lambda: smartlog.show_main(), "Alt+L")
    menu.addCommand("Timer", lambda: smartlog.show_timer_widget(), "Alt+T")
    menu.addSeparator()
    menu.addCommand("&about", lambda: smartlog.show_about_window())


init()


def install_event_filter():
    """Install the idle detect event filter to Nuke's main window.

    Notes:
        It turned out that other tools that call Nuke's main window will no
        longer work when installing the event filter by calling the main window
        on global scope and directly. Instead, we initialize this function here
        delayed and in a separate function. This will make calling Nuke's main
        window still possible for all upcoming tools.

    """
    nuke_funcs.main_window().installEventFilter(OBSERVER)


# Install event filter delayed, otherwise this breaks calling Nuke's main
# window in all upcoming calls of other tools.
OBSERVER = idle.ChangeObserver()
QtCore.QTimer.singleShot(1000, install_event_filter)

IDLE_OBSERVER = idle.IdleObserver()
IDLE_OBSERVER.start()
